@@ -1,4 +1,4 @@
-/* $Id: libgdamm.h,v 1.3 2003/10/12 09:50:12 murrayc Exp $ */
+/* $Id: libgdamm.h 1042 2007-03-09 22:15:06Z arminb $ */
 /* libgdamm - a C++ wrapper for libgda
  *
  * Copyright 1999-2001 Free Software Foundation
@@ -37,6 +37,14 @@ extern const int libgdamm_micro_version;
 #include <libgdamm/config.h>
 #include <libgdamm/connection.h>
 #include <libgdamm/datamodel.h>
-#include <libgdamm/error.h>
+#include <libgdamm/connectionevent.h>
+#include <libgdamm/datamodelarray.h>
+#include <libgdamm/datamodelquery.h>
+#include <libgdamm/query.h>
+#include <libgdamm/queryfieldagg.h>
+#include <libgdamm/queryfieldall.h>
+#include <libgdamm/queryfieldfield.h>
+#include <libgdamm/queryfieldvalue.h>
+#include <libgdamm/serveroperation.h>
 
 #endif /* #ifndef LIBGDAMM_H */
